@@ -33,6 +33,7 @@ def search(
     wrap_text=False,
     json=False,
     save=False,
+    verbose=True,
 ):
     """
     Function to query Ensembl for genes based on species and free form search terms.
@@ -53,6 +54,7 @@ def search(
     - wrap_text       If True, displays data frame with wrapped text for easy reading. Default: False.
     - json            If True, returns results in json format instead of data frame. Default: False.
     - save            If True, the data frame is saved as a csv in the current directory (default: False).
+    - verbose         True/False whether to print progress information. Default True.
 
     Returns a data frame with the query results.
 
@@ -133,7 +135,8 @@ def search(
     else:
         db = db[0]
 
-    logging.info(f"Fetching results from database: {db}")
+    if verbose:
+        logging.info(f"Fetching results from database: {db}")
 
     ## Connect to data base
     try:
@@ -150,6 +153,7 @@ def search(
                 password="",
                 port=5306,
             )
+
         except Exception as e:
             logging.error(f"The Ensembl server returned the following error: {e}")
 
@@ -162,7 +166,7 @@ def search(
     for i, searchword in enumerate(searchwords):
         if id_type == "gene":
             query = f"""
-            SELECT gene.stable_id, xref.display_label, gene.description, xref.description, gene.biotype
+            SELECT gene.stable_id AS 'ensembl_id', xref.display_label  AS 'gene_name', gene.description AS 'ensembl_description', xref.description AS 'ext_ref_description', gene.biotype  AS 'biotype'
             FROM gene
             LEFT JOIN xref ON gene.display_xref_id = xref.xref_id
             WHERE (gene.description LIKE '%{searchword}%' OR xref.description LIKE '%{searchword}%' OR xref.display_label LIKE '%{searchword}%')
@@ -170,8 +174,9 @@ def search(
 
             # Fetch the search results from the host using the specified query
             df_temp = pd.read_sql(query, con=db_connection)
+
             # Order by ENSEMBL ID (I am using pandas for this instead of SQL to increase speed)
-            df_temp = df_temp.sort_values("stable_id").reset_index(drop=True)
+            df_temp = df_temp.sort_values("ensembl_id").reset_index(drop=True)
 
             # If andor="or", keep all results
             if andor == "or":
@@ -189,12 +194,12 @@ def search(
                     df = df_temp.copy()
                 # Only keep overlapping results in master data frame
                 else:
-                    val = np.intersect1d(df["stable_id"], df_temp["stable_id"])
-                    df = df[df.stable_id.isin(val)]
+                    val = np.intersect1d(df["ensembl_id"], df_temp["ensembl_id"])
+                    df = df[df.ensembl_id.isin(val)]
 
         if id_type == "transcript":
             query = f"""
-            SELECT transcript.stable_id, xref.display_label, transcript.description, xref.description, transcript.biotype
+            SELECT transcript.stable_id AS 'ensembl_id', xref.display_label  AS 'gene_name', transcript.description AS 'ensembl_description', xref.description AS 'ext_ref_description', transcript.biotype  AS 'biotype'
             FROM transcript
             LEFT JOIN xref ON transcript.display_xref_id = xref.xref_id
             WHERE (transcript.description LIKE '%{searchword}%' OR xref.description LIKE '%{searchword}%' OR xref.display_label LIKE '%{searchword}%')
@@ -203,7 +208,7 @@ def search(
             # Fetch the search results from the host using the specified query
             df_temp = pd.read_sql(query, con=db_connection)
             # Order by ENSEMBL ID (I am using pandas for this instead of SQL to increase speed)
-            df_temp = df_temp.sort_values("stable_id").reset_index(drop=True)
+            df_temp = df_temp.sort_values("ensembl_id").reset_index(drop=True)
 
             # If andor="or", keep all results
             if andor == "or":
@@ -221,20 +226,8 @@ def search(
                     df = df_temp.copy()
                 # Only keep overlapping results in master data frame
                 else:
-                    val = np.intersect1d(df["stable_id"], df_temp["stable_id"])
-                    df = df[df.stable_id.isin(val)]
-
-    # Rename columns
-    df = df.rename(
-        columns={
-            "stable_id": "ensembl_id",
-            "display_label": "gene_name",
-            "biotype": "biotype",
-        }
-    )
-    # Changing description columns name by column index since they were returned with the same name ("description")
-    df.columns.values[2] = "ensembl_description"
-    df.columns.values[3] = "ext_ref_description"
+                    val = np.intersect1d(df["ensembl_id"], df_temp["ensembl_id"])
+                    df = df[df.ensembl_id.isin(val)]
 
     # Remove any duplicate search results from the master data frame and reset the index
     df = df.drop_duplicates().reset_index(drop=True)
@@ -242,16 +235,19 @@ def search(
     # If limit is not None, keep only the first {limit} rows
     if limit != None:
         # Print number of genes/transcripts found versus fetched
-        logging.info(f"Returning {limit} matches of {len(df)} total matches found.")
+        if verbose:
+            logging.info(f"Returning {limit} matches of {len(df)} total matches found.")
         # Remove all but limit rows
         df = df.head(limit)
 
     else:
         # Print number of genes/transcripts fetched
-        logging.info(f"Total matches found: {len(df)}.")
+        if verbose:
+            logging.info(f"Total matches found: {len(df)}.")
 
     # Print query time
-    logging.info(f"Query time: {round(time.time() - start_time, 2)} seconds.")
+    if verbose:
+        logging.info(f"Query time: {round(time.time() - start_time, 2)} seconds.")
 
     # Add URL to gene summary on Ensembl
     df["url"] = (
