@@ -139,6 +139,14 @@ def main():
             "Default: Standard out."
         ),
     )
+    parser_ref.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
     parser_ref.add_argument(
         "-s",
         "--species",
@@ -147,6 +155,7 @@ def main():
         dest="species_deprecated",
         help="DEPRECATED - use positional argument instead. Species for which the FTPs will be fetched, e.g. homo_sapiens.",
     )
+   
 
     ## gget search subparser
     search_desc = (
@@ -224,6 +233,14 @@ def main():
             "Default: Standard out."
         ),
     )
+    parser_gget.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
     parser_gget.add_argument(
         "-sw",
         "--searchwords",
@@ -248,6 +265,7 @@ def main():
         required=False,
         help="DEPRECATED - json is now the default output format (convert to csv using flag [--csv]).",
     )
+   
 
     ## gget info subparser
     info_desc = "Fetch gene and transcript metadata using Ensembl IDs."
@@ -263,20 +281,20 @@ def main():
         help="One or more Ensembl, WormBase or FlyBase IDs.",
     )
     parser_info.add_argument(
-        "-pdb",
-        "--pdb",
-        default=False,
-        action="store_true",
+        "-n",
+        "--ncbi",
+        default=True,
+        action="store_false",
         required=False,
-        help="Also returns PDB IDs (might increase run time).",
+        help="TURN OFF results from NCBI database.",
     )
     parser_info.add_argument(
-        "-eo",
-        "--ensembl_only",
-        default=False,
-        action="store_true",
+        "-u",
+        "--uniprot",
+        default=True,
+        action="store_false",
         required=False,
-        help="Only returns results from Ensembl (excludes PDB, UniProt, and NCBI results).",
+        help="TURN OFF results from UniProt database.",
     )
     parser_info.add_argument(
         "-csv",
@@ -286,6 +304,14 @@ def main():
         required=False,
         help="Returns results in csv format instead of json.",
     )
+    parser_info.add_argument(
+        "-pdb",
+        "--pdb",
+        default=False,
+        action="store_true",
+        required=False,
+        help="Also returns PDB IDs (might increase run time).",
+    )
     parser_info.add_argument(
         "-q",
         "--quiet",
@@ -304,6 +330,14 @@ def main():
             "Default: Standard out."
         ),
     )
+    parser_info.add_argument(
+        "-eo",
+        "--ensembl_only",
+        default=False,
+        action="store_true",
+        required=False,
+        help="DEPRECATED - only returns results from Ensembl (excludes PDB, UniProt, and NCBI results).",
+    )
     parser_info.add_argument(
         "-id",
         "--ens_ids",
@@ -371,6 +405,14 @@ def main():
             "Default: Standard out."
         ),
     )
+    parser_seq.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
     parser_seq.add_argument(
         "-id",
         "--ens_ids",
@@ -394,6 +436,7 @@ def main():
         required=False,
         help="DEPRECATED - use True/False flag 'translate' instead.",
     )
+ 
 
     ## gget muscle subparser
     muscle_desc = "Align multiple nucleotide or amino acid sequences against each other (using the Muscle v5 algorithm)."
@@ -431,6 +474,14 @@ def main():
             "Default: 'None' -> Standard out in Clustal format."
         ),
     )
+    parser_muscle.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
     parser_muscle.add_argument(
         "-fa",
         "--fasta",
@@ -439,6 +490,7 @@ def main():
         dest="fasta_deprecated",
         help="DEPRECATED - use positional argument instead. Path to fasta file containing the sequences to be aligned.",
     )
+  
 
     ## gget blast subparser
     blast_desc = "BLAST a nucleotide or amino acid sequence against any BLAST database."
@@ -622,6 +674,14 @@ def main():
             "Default: Standard out."
         ),
     )
+    parser_blat.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
     parser_blat.add_argument(
         "-seq",
         "--sequence",
@@ -638,6 +698,7 @@ def main():
         required=False,
         help="DEPRECATED - json is now the default output format (convert to csv using flag [--csv]).",
     )
+    
 
     ## gget enrichr subparser
     enrichr_desc = "Perform an enrichment analysis on a list of genes using Enrichr."
@@ -692,6 +753,14 @@ def main():
             "Default: Standard out."
         ),
     )
+    parser_enrichr.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
     parser_enrichr.add_argument(
         "-g",
         "--genes",
@@ -709,6 +778,7 @@ def main():
         required=False,
         help="DEPRECATED - json is now the default output format (convert to csv using flag [--csv]).",
     )
+  
 
     ## gget archs4 subparser
     archs4_desc = "Find the most correlated genes or the tissue expression atlas of a gene using data from the human and mouse RNA-seq database ARCHS4 (https://maayanlab.cloud/archs4/)."
@@ -799,6 +869,14 @@ def main():
             "Default: Standard out."
         ),
     )
+    parser_archs4.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
     parser_archs4.add_argument(
         "-g",
         "--gene",
@@ -815,6 +893,7 @@ def main():
         required=False,
         help="DEPRECATED - json is now the default output format (convert to csv using flag [--csv]).",
     )
+    
 
     ## gget setup subparser
     setup_desc = "Install third-party dependencies for a specified gget module."
@@ -889,6 +968,14 @@ def main():
             "Default: ./[date_time]_gget_alphafold_prediction"
         ),
     )
+    parser_alphafold.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
 
     ## gget pdb subparser
     pdb_desc = "Query RCSB PDB for the protein structutre/metadata of a given PDB ID."
@@ -967,6 +1054,14 @@ def main():
             "Default: Standard out."
         ),
     )
+    parser_pdb.add_argument(
+        "-q",
+        "--quiet",
+        default=True,
+        action="store_false",
+        required=False,
+        help="Does not print progress information.",
+    )
 
     # gpt parser arguments
     gpt_desc = "Generates natural language text based on a given prompt using the OpenAI API's 'openai.ChatCompletion.create' endpoint."
@@ -1152,6 +1247,7 @@ def main():
             seqtype=args.seqtype,
             assembly=args.assembly,
             json=args.csv,
+            verbose=args.quiet,
         )
 
         # Check if the function returned something
@@ -1257,6 +1353,7 @@ def main():
             gene_count=args.gene_count,
             species=args.species,
             json=args.csv,
+            verbose=args.quiet,
         )
 
         # Check if the function returned something
@@ -1336,13 +1433,13 @@ def main():
         which_clean = args.which.split(",")
 
         if args.species:
-
             # Query Ensembl for requested FTPs using function ref
             ref_results = ref(
                 species=args.species,
                 which=which_clean,
                 release=args.release,
                 ftp=args.ftp,
+                verbose=args.quiet,
             )
 
             # Print or save list of URLs (ftp=True)
@@ -1460,6 +1557,7 @@ def main():
             andor=args.andor,
             limit=args.limit,
             json=args.csv,
+            verbose=args.quiet,
         )
 
         # Save search results if args.out specified
@@ -1518,6 +1616,7 @@ def main():
             database=args.database,
             ensembl=args.ensembl,
             json=args.csv,
+            verbose=args.quiet,
         )
 
         # Check if the function returned something
@@ -1556,7 +1655,11 @@ def main():
         if args.id_deprecated and not args.ens_ids:
             args.ens_ids = args.id_deprecated
             logging.warning(
-                "The [-id][--genes] argument is deprecated, please use positional argument [ens_ids] instead."
+                "The [-id][--genes] argument is deprecated, please use arguments [ens_ids] instead."
+            )
+        if args.ensembl_only:
+            logging.warning(
+                "The [-eo][--ensembl_only] argument is deprecated, please use arguments [ncbi] and [uniprot] instead."
             )
         if not args.id_deprecated and not args.ens_ids:
             parser_info.error("the following arguments are required: ens_ids")
@@ -1575,6 +1678,8 @@ def main():
         # Look up requested Ensembl IDs
         info_results = info(
             ids_clean_final,
+            ncbi=args.ncbi,
+            uniprot=args.uniprot,
             pdb=args.pdb,
             ensembl_only=args.ensembl_only,
             expand=args.expand,
@@ -1641,6 +1746,7 @@ def main():
             seqtype=args.seqtype,
             isoforms=args.isoforms,
             transcribe=args.transcribe,
+            verbose=args.quiet,
         )
 
         # Save in specified directory if -o specified
@@ -1689,6 +1795,8 @@ def main():
             pdb_id=args.pdb_id,
             resource=args.resource,
             identifier=args.identifier,
+            verbose=args.quiet,
+            
         )
 
         if pdb_results:
